@@ -1,3 +1,3 @@
 #!/bin/sh
 # SPDX-License-Identifier: GPL-3.0-or-later
-service bind9 restart
+service named restart
