@@ -1,4 +1,5 @@
-/* Licensed under BSD-MIT - see LICENSE file for details */
+/* SPDX-License-Identifier: MIT
+ * Source: https://ccodearchive.net/info/asprintf.html */
 #ifndef CCAN_ASPRINTF_H
 #define CCAN_ASPRINTF_H
 #include "config.h"
@@ -12,7 +13,7 @@
  */
 char *PRINTF_FMT(1, 2) afmt(const char *fmt, ...);
 
-#if HAVE_ASPRINTF || defined(__USE_FORTIFY_LEVEL)
+#if HAVE_ASPRINTF
 #include <stdio.h>
 #else
 #include <stdarg.h>
