@@ -6,8 +6,8 @@
  *	(c) 2006 Robert Spalek <robert@ucw.cz>
  *	(c) 2007 Pavel Charvat <pchar@ucw.cz>
  *
- *	This software may be freely distributed and used according to the terms
- *	of the GNU Lesser General Public License.
+ *	SPDX-License-Identifier: LGPL-2.1-or-later
+ *	Source: https://www.ucw.cz/libucw/
  */
 
 #ifndef _UCW_LIB_H
