@@ -17,9 +17,6 @@ struct tls_ctx;
 struct tls_client_ctx;
 struct io_stream_data;
 
-/** Initializes the protocol layers managed by io. */
-void io_protolayers_init(void);
-
 /** Bind address into a file-descriptor (only, no libuv).  type is e.g. SOCK_DGRAM */
 int io_bind(const struct sockaddr *addr, int type, const endpoint_flags_t *flags);
 /** Initialize a UDP handle and start listening. */
@@ -45,7 +42,7 @@ void tcp_timeout_trigger(uv_timer_t *timer);
  * \param family = AF_*
  * \param has_tls has meanings only when type is SOCK_STREAM */
 int io_create(uv_loop_t *loop, struct session2 **out_session, int type,
-              unsigned family, enum protolayer_grp grp,
+              unsigned family, enum kr_proto grp,
               struct protolayer_data_param *layer_param,
               size_t layer_param_count, bool outgoing);
 void io_free(uv_handle_t *handle);
