@@ -11,14 +11,9 @@
 
 int pkt_renew(knot_pkt_t *pkt, const knot_dname_t *name, uint16_t type)
 {
-	/* Clear the packet if needed. */
-	if (pkt->rrset_count != 0 || !knot_dname_is_equal(knot_pkt_qname(pkt), name)
-	    || knot_pkt_qtype(pkt) != type || knot_pkt_qclass(pkt) != KNOT_CLASS_IN) {
-		int ret = kr_pkt_recycle(pkt);
-		if (ret) return kr_error(ret);
-		ret = knot_pkt_put_question(pkt, name, KNOT_CLASS_IN, type);
-		if (ret) return kr_error(ret);
-	}
+	knot_pkt_clear(pkt);
+	int ret = knot_pkt_put_question(pkt, name, KNOT_CLASS_IN, type);
+	if (ret) return kr_error(ret);
 
 	pkt->parsed = pkt->size = KR_PKT_SIZE_NOWIRE;
 	knot_wire_set_qr(pkt->wire);
