@@ -3,6 +3,7 @@
  */
 
 #include "lib/cache/impl.h"
+#include "lib/cache/top.h"
 
 #include "lib/dnssec/ta.h"
 #include "lib/layer/iterate.h"
@@ -122,16 +123,18 @@ int peek_nosync(kr_layer_t *ctx, knot_pkt_t *pkt)
 		knot_db_val_t key = key_exact_type_maypkt(k, qry->stype);
 		knot_db_val_t val = { NULL, 0 };
 		ret = cache_op(cache, read, &key, &val, 1);
+		size_t whole_val_len = val.len;
 		if (!ret) {
 			/* found an entry: test conditions, materialize into pkt, etc. */
 			ret = found_exact_hit(qry, pkt, val, lowest_rank);
 		}
-	}
-	if (!ret) {
-		return KR_STATE_DONE;
-	} else if (kr_fails_assert(ret == kr_error(ENOENT))) {
-		VERBOSE_MSG(qry, "=> exact hit error: %d %s\n", ret, kr_strerror(ret));
-		return ctx->state;
+		if (!ret) {
+			kr_cache_top_access(req, key.data, key.len, whole_val_len, "peek_nosync:exact");  // hits only
+			return KR_STATE_DONE;
+		} else if (kr_fails_assert(ret == kr_error(ENOENT))) {
+			VERBOSE_MSG(qry, "=> exact hit error: %d %s\n", ret, kr_strerror(ret));
+			return ctx->state;
+		}
 	}
 
 	/* Avoid aggressive answers in STUB mode.
@@ -274,6 +277,7 @@ int peek_nosync(kr_layer_t *ctx, knot_pkt_t *pkt)
 		ret = entry2answer(&ans, AR_SOA, eh, knot_db_val_bound(val),
 				   k->zname, KNOT_RRTYPE_SOA, new_ttl);
 		if (ret) return ctx->state;
+		kr_cache_top_access(req, key.data, key.len, val.len, "peek_nosync:SOA");  // hits only
 	}
 
 	/* Find our target RCODE. */
@@ -557,7 +561,9 @@ static int try_wild(struct key *k, struct answer *ans, const knot_dname_t *clenc
 	/* Find the record. */
 	knot_db_val_t val = { NULL, 0 };
 	int ret = cache_op(cache, read, &key, &val, 1);
+	size_t whole_val_len = 0;
 	if (!ret) {
+		whole_val_len = val.len; // original size, before seeking
 		ret = entry_h_seek(&val, type);
 	}
 	if (ret) {
@@ -592,6 +598,7 @@ static int try_wild(struct key *k, struct answer *ans, const knot_dname_t *clenc
 			ret, (int)new_ttl);
 	if (ret) return kr_error(ret);
 	ans->rcode = PKT_NOERROR;
+	kr_cache_top_access(qry->request, key.data, key.len, whole_val_len, "try_wild"); // hits only
 	return kr_ok();
 }
 
@@ -652,10 +659,10 @@ static int closest_NS(struct kr_cache *cache, struct key *k, entry_list_t el,
 	bool exact_match = true;
 	bool need_zero = true;
 	/* Inspect the NS/xNAME entries, shortening by a label on each iteration. */
+	knot_db_val_t key, val;
 	do {
 		k->buf[0] = zlf_len;
-		knot_db_val_t key = key_exact_type(k, KNOT_RRTYPE_NS);
-		knot_db_val_t val;
+		key = key_exact_type(k, KNOT_RRTYPE_NS);
 		int ret = cache_op(cache, read, &key, &val, 1);
 		if (ret == kr_error(ENOENT)) goto next_label;
 		if (kr_fails_assert(ret == 0)) {
@@ -680,8 +687,7 @@ static int closest_NS(struct kr_cache *cache, struct key *k, entry_list_t el,
 			if (ret < 0) goto next_label; else
 			if (!ret) {
 				/* We found our match. */
-				k->zlf_len = zlf_len;
-				return kr_ok();
+				goto success;
 			}
 		}
 		const int el_count = only_NS ? EL_NS + 1 : EL_LENGTH;
@@ -692,8 +698,7 @@ static int closest_NS(struct kr_cache *cache, struct key *k, entry_list_t el,
 			if (ret < 0) goto next_label; else
 			if (!ret) {
 				/* We found our match. */
-				k->zlf_len = zlf_len;
-				return kr_ok();
+				goto success;
 			}
 		}
 
@@ -721,6 +726,12 @@ static int closest_NS(struct kr_cache *cache, struct key *k, entry_list_t el,
 			return kr_error(ENOENT);
 		}
 	} while (true);
+
+success:
+	k->zlf_len = zlf_len;
+	if (qry) // usage from kr_cache_closest_apex() doesn't have a qry
+		kr_cache_top_access(qry->request, key.data, key.len, val.len, "closest_NS"); // hits only
+	return kr_ok();
 }
 
 static int check_NS_entry(struct key *k, const knot_db_val_t entry, const int i,
