@@ -81,6 +81,7 @@ enum kr_log_group {
 	LOG_GRP_EDE,
 	LOG_GRP_RULES,
 	LOG_GRP_PROTOLAYER,
+	LOG_GRP_DEFER,
 	/* ^^ Add new log groups above ^^. */
 	LOG_GRP_REQDBG, /* Must be first non-displayed entry in enum! */
 };
@@ -109,7 +110,7 @@ enum kr_log_group {
 #define LOG_GRP_VALIDATOR_TAG		"valdtr"	/**< ``valdtr``: operations related to validate layer */
 #define LOG_GRP_RESOLVER_TAG		"resolv"	/**< ``resolv``: operations related to resolving */
 #define LOG_GRP_SELECTION_TAG		"select"	/**< ``select``: operations related to server selection */
-#define LOG_GRP_ZCUT_TAG		"zoncut"	/**< ``zonecut``: operations related to zone cut */
+#define LOG_GRP_ZCUT_TAG		"zoncut"	/**< ``zoncut``: operations related to zone cut */
 #define LOG_GRP_COOKIES_TAG		"cookie"	/**< ``cookie``: operations related to cookies */
 #define LOG_GRP_STATISTICS_TAG		"statis"	/**< ``statis``: operations related to statistics */
 #define LOG_GRP_REBIND_TAG		"rebind"	/**< ``rebind``: operations related to rebinding */
@@ -135,6 +136,7 @@ enum kr_log_group {
 #define LOG_GRP_EDE_TAG			"exterr"	/**< ``exterr``: extended error module */
 #define LOG_GRP_RULES_TAG		"rules"		/**< ``rules``: new policy rules (their processing) */
 #define LOG_GRP_PROTOLAYER_TAG		"prlayr"	/**< ``prlayr``: protocol layer system (session2) */
+#define LOG_GRP_DEFER_TAG		"defer" 	/**< ``defer``: prioritization of requests */
 #define LOG_GRP_REQDBG_TAG		"reqdbg"	/**< ``reqdbg``: debug logs enabled by policy actions */
 ///@}
 
