@@ -155,10 +155,9 @@ struct kr_context
 	/** Default kr_request flags.  For startup defaults see init_resolver() */
 	struct kr_qflags options;
 
-	/** Default EDNS towards *both* clients and upstream.
-	 * LATER: consider splitting the two, e.g. allow separately
-	 * configured limits for UDP packet size (say, LAN is under control). */
+	/** Default EDNS towards clients */
 	knot_rrset_t *downstream_opt_rr;
+	/** Default EDNS towards authoritative servers or forward targets */
 	knot_rrset_t *upstream_opt_rr;
 
 	trie_t *trust_anchors;
@@ -251,7 +250,11 @@ struct kr_request {
 		uint32_t price_factor16;
 		size_t size; /**< query packet size */
 		int32_t stream_id; /**< HTTP/2 stream ID for DoH requests */
-		kr_http_header_array_t headers;  /**< HTTP/2 headers for DoH requests */
+  		/** HTTP/2 headers for DoH requests
+		 *
+		 * Note that this owns malloc-ed memory inside (outside ->pool).
+		 */
+		kr_http_header_array_t headers;
 	} qsource;
 	struct {
 		unsigned rtt;                  /**< Current upstream RTT */
@@ -266,7 +269,6 @@ struct kr_request {
 	bool auth_validated; /**< see answ_validated ^^ ; TODO */
 	bool stale_accounted;
 	bool ratelimited; /**< this request shot over the rate limit */
-
 	/** Overall rank for the request.
 	 *
 	 * Values from kr_rank, currently just KR_RANK_SECURE and _INITIAL.
@@ -276,6 +278,9 @@ struct kr_request {
 	 */
 	uint8_t rank;
 
+	uint8_t rule_score_apply;
+	uint8_t rule_score_log;
+
 	struct kr_rplan rplan;
 	trace_log_f trace_log; /**< Logging tracepoint */
 	trace_callback_f trace_finish; /**< Request finish tracepoint */
@@ -293,6 +298,7 @@ struct kr_request {
 	alloc_wire_f alloc_wire_cb; /**< CB to allocate answer wire (can be NULL). */
 	kr_rule_tags_t rule_tags; /**< TagSet applying to this request. */
 	struct kr_extended_error extended_error;  /**< EDE info; don't modify directly, use kr_request_set_extended_error() */
+	struct kr_cache_top_context cache_top_context;
 };
 
 /** Initializer for an array of *_selected. */
