@@ -3,7 +3,7 @@ import os
 import socket
 from typing import Any, Dict, List, Literal, Optional, Tuple, Union
 
-from knot_resolver.constants import API_SOCK_FILE, RUN_DIR, VERSION
+from knot_resolver.constants import API_SOCK_FILE, RUN_DIR, VERSION, WORKERS_SUPPORT
 from knot_resolver.datamodel.cache_schema import CacheSchema
 from knot_resolver.datamodel.defer_schema import DeferSchema
 from knot_resolver.datamodel.dns64_schema import Dns64Schema
@@ -21,7 +21,6 @@ from knot_resolver.datamodel.rate_limiting_schema import RateLimitingSchema
 from knot_resolver.datamodel.templates import KRESD_CONFIG_TEMPLATE, POLICY_LOADER_CONFIG_TEMPLATE
 from knot_resolver.datamodel.types import EscapedStr, IntPositive, WritableDir
 from knot_resolver.datamodel.view_schema import ViewSchema
-from knot_resolver.datamodel.webmgmt_schema import WebmgmtSchema
 from knot_resolver.utils.modeling import ConfigSchema
 from knot_resolver.utils.modeling.base_schema import lazy_default
 from knot_resolver.utils.modeling.exceptions import AggregateDataValidationError, DataValidationError
@@ -33,16 +32,18 @@ logger = logging.getLogger(__name__)
 
 def _cpu_count() -> Optional[int]:
     try:
-        return len(os.sched_getaffinity(0))
-    except (NotImplementedError, AttributeError):
-        logger.warning("The number of usable CPUs could not be determined using 'os.sched_getaffinity()'.")
+        return len(os.sched_getaffinity(0))  # type: ignore[attr-defined]
+    except (NotImplementedError, AttributeError) as e:
         cpus = os.cpu_count()
         if cpus is None:
-            logger.warning("The number of usable CPUs could not be determined using 'os.cpu_count()'.")
+            logger.warning(
+                "The number of usable CPUs could not be determined using"
+                f" 'os.sched_getaffinity()' or 'os.cpu_count()':\n{e}"
+            )
         return cpus
 
 
-def _workers_max_count() -> int:
+def workers_max_count() -> int:
     c = _cpu_count()
     if c:
         return c * 10
@@ -94,9 +95,7 @@ class KresConfig(ConfigSchema):
         hostname: Internal DNS resolver hostname. Default is machine hostname.
         rundir: Directory where the resolver can create files and which will be it's cwd.
         workers: The number of running kresd (Knot Resolver daemon) workers. If set to 'auto', it is equal to number of CPUs available.
-        max_workers: The maximum number of workers allowed. Cannot be changed in runtime.
         management: Configuration of management HTTP API.
-        webmgmt: Configuration of legacy web management endpoint.
         options: Fine-tuning global parameters of DNS resolver operation.
         network: Network connections and protocols configuration.
         views: List of views and its configuration.
@@ -104,10 +103,10 @@ class KresConfig(ConfigSchema):
         forward: List of Forward Zones and its configuration.
         fallback: Config for fallback on resolution failure.
         cache: DNS resolver cache configuration.
-        dnssec: Disable DNSSEC, enable with defaults or set new configuration.
-        dns64: Disable DNS64 (RFC 6147), enable with defaults or set new configuration.
+        dnssec: DNSSEC configuration.
+        dns64: DNS64 (RFC 6147) configuration.
         logging: Logging and debugging configuration.
-        monitoring: Metrics exposisition configuration (Prometheus, Graphite)
+        monitoring: Metrics exposition configuration (Prometheus, Graphite)
         lua: Custom Lua configuration.
         rate_limiting: Configuration of rate limiting.
         defer: Configuration of request prioritization (defer).
@@ -118,9 +117,7 @@ class KresConfig(ConfigSchema):
         hostname: Optional[EscapedStr] = None
         rundir: WritableDir = lazy_default(WritableDir, str(RUN_DIR))
         workers: Union[Literal["auto"], IntPositive] = IntPositive(1)
-        max_workers: IntPositive = IntPositive(WORKERS_MAX)
         management: ManagementSchema = lazy_default(ManagementSchema, {"unix-socket": str(API_SOCK_FILE)})
-        webmgmt: Optional[WebmgmtSchema] = None
         options: OptionsSchema = OptionsSchema()
         network: NetworkSchema = NetworkSchema()
         views: Optional[List[ViewSchema]] = None
@@ -128,11 +125,11 @@ class KresConfig(ConfigSchema):
         forward: Optional[List[ForwardSchema]] = None
         fallback: FallbackSchema = FallbackSchema()
         cache: CacheSchema = lazy_default(CacheSchema, {})
-        dnssec: Union[bool, DnssecSchema] = True
-        dns64: Union[bool, Dns64Schema] = False
+        dnssec: DnssecSchema = DnssecSchema()
+        dns64: Dns64Schema = Dns64Schema()
         logging: LoggingSchema = LoggingSchema()
         monitoring: MonitoringSchema = MonitoringSchema()
-        rate_limiting: Optional[RateLimitingSchema] = None
+        rate_limiting: RateLimitingSchema = RateLimitingSchema()
         defer: DeferSchema = DeferSchema()
         lua: LuaSchema = LuaSchema()
 
@@ -142,9 +139,7 @@ class KresConfig(ConfigSchema):
     hostname: EscapedStr
     rundir: WritableDir
     workers: IntPositive
-    max_workers: IntPositive
     management: ManagementSchema
-    webmgmt: Optional[WebmgmtSchema]
     options: OptionsSchema
     network: NetworkSchema
     views: Optional[List[ViewSchema]]
@@ -152,11 +147,11 @@ class KresConfig(ConfigSchema):
     forward: Optional[List[ForwardSchema]]
     fallback: FallbackSchema
     cache: CacheSchema
-    dnssec: Union[Literal[False], DnssecSchema]
-    dns64: Union[Literal[False], Dns64Schema]
+    dnssec: DnssecSchema
+    dns64: Dns64Schema
     logging: LoggingSchema
     monitoring: MonitoringSchema
-    rate_limiting: Optional[RateLimitingSchema]
+    rate_limiting: RateLimitingSchema
     defer: DeferSchema
     lua: LuaSchema
 
@@ -166,7 +161,21 @@ class KresConfig(ConfigSchema):
         return obj.hostname
 
     def _workers(self, obj: Raw) -> Any:
+        no_workers_support_msg = (
+            "On this system, you cannot run more than one worker because "
+            "SO_REUSEPORT (Linux) or SO_REUSEPORT_LB (FreeBSD) socket option is not supported."
+        )
+        if not WORKERS_SUPPORT and (int(obj.workers) > 1):
+            raise ValueError(no_workers_support_msg)
+
         if obj.workers == "auto":
+            if not WORKERS_SUPPORT:
+                logger.info(
+                    "Running on system without support for multiple workers,"
+                    f"' workers' configuration automatically set to 1. {no_workers_support_msg}"
+                )
+                return IntPositive(1)
+
             count = _cpu_count()
             if count:
                 return IntPositive(count)
@@ -174,18 +183,9 @@ class KresConfig(ConfigSchema):
                 "The number of available CPUs to automatically set the number of running 'kresd' workers could not be determined."
                 "The number of workers can be configured manually in 'workers' option."
             )
+
         return obj.workers
 
-    def _dnssec(self, obj: Raw) -> Any:
-        if obj.dnssec is True:
-            return DnssecSchema()
-        return obj.dnssec
-
-    def _dns64(self, obj: Raw) -> Any:
-        if obj.dns64 is True:
-            return Dns64Schema()
-        return obj.dns64
-
     def _validate(self) -> None:
         # warn about '/management/unix-socket' not located in '/rundir'
         if self.management.unix_socket and self.management.unix_socket.to_path().parent != self.rundir.to_path():
@@ -196,7 +196,7 @@ class KresConfig(ConfigSchema):
             )
 
         # enforce max-workers config
-        workers_max = _workers_max_count()
+        workers_max = workers_max_count()
         if int(self.workers) > workers_max:
             raise ValueError(
                 f"can't run with more workers than the recommended maximum {workers_max} or hardcoded {WORKERS_MAX}"
