@@ -7,9 +7,9 @@ class DeferSchema(ConfigSchema):
     Configuration of request prioritization (defer).
 
     ---
-    enabled: Use request prioritization.
+    enable: Use request prioritization.
     log_period: Minimal time between two log messages, or '0s' to disable.
     """
 
-    enabled: bool = False
+    enable: bool = False
     log_period: TimeUnit = TimeUnit("0s")
