@@ -5,6 +5,7 @@ from .types import (
     DomainName,
     EscapedStr,
     EscapedStr32B,
+    FloatNonNegative,
     IDPattern,
     Int0_32,
     Int0_512,
@@ -37,6 +38,7 @@ __all__ = [
     "DomainName",
     "EscapedStr",
     "EscapedStr32B",
+    "FloatNonNegative",
     "IDPattern",
     "Int0_32",
     "Int0_512",
