@@ -52,17 +52,6 @@ class _FixCounter:
         return self._counter >= FIX_COUNTER_ATTEMPTS_MAX
 
 
-async def _deny_max_worker_changes(
-    config_old: KresConfig, config_new: KresConfig, force: bool = False
-) -> Result[None, str]:
-    if config_old.max_workers != config_new.max_workers:
-        return Result.err(
-            "Changing 'max-workers', the maximum number of workers allowed to run, is not allowed at runtime."
-        )
-
-    return Result.ok(None)
-
-
 async def _subprocess_desc(subprocess: Subprocess) -> object:
     return {
         "type": subprocess.type.name,
@@ -131,8 +120,6 @@ class KresManager:  # pylint: disable=too-many-instance-attributes
                 config.nsid,
                 config.hostname,
                 config.workers,
-                config.max_workers,
-                config.webmgmt,
                 config.options,
                 config.network,
                 config.forward,
@@ -163,9 +150,6 @@ class KresManager:  # pylint: disable=too-many-instance-attributes
         # register callback that reloads files (TLS cert files) if selected configuration has not been changed
         await config_store.register_on_change_callback(only_on_no_changes_update(config_nodes)(files_reload))
 
-        # register controller config change listeners
-        await config_store.register_verifier(_deny_max_worker_changes)
-
     async def _spawn_new_worker(self, config: KresConfig) -> None:
         subprocess = await self._controller.create_subprocess(config, SubprocessType.KRESD)
         await subprocess.start()
@@ -288,8 +272,15 @@ class KresManager:  # pylint: disable=too-many-instance-attributes
             )
 
     async def set_new_tls_sticket_secret(self, config: KresConfig, force: bool = False) -> None:
+        if int(config.workers) == 1:
+            logger.info(
+                "There is no need to synchronize the TLS session secret across all workers"
+                " because only one kresd worker is configured - skipping auto-generation"
+            )
+            return
+
         if config.network.tls.sticket_secret or config.network.tls.sticket_secret_file:
-            logger.debug("User-configured TLS resumption secret found - skipping auto-generation.")
+            logger.debug("User-configured TLS resumption secret found - skipping auto-generation")
             return
 
         logger.debug("Creating TLS session ticket secret")
@@ -307,8 +298,8 @@ class KresManager:  # pylint: disable=too-many-instance-attributes
                 await self._rolling_restart(config)
                 await self._ensure_number_of_children(config, int(config.workers))
 
-                if self._is_gc_running() != bool(config.cache.garbage_collector):
-                    if config.cache.garbage_collector:
+                if self._is_gc_running() != config.cache.garbage_collector.enable:
+                    if config.cache.garbage_collector.enable:
                         logger.debug("Starting cache GC")
                         await self._start_gc(config)
                     else:
@@ -336,6 +327,13 @@ class KresManager:  # pylint: disable=too-many-instance-attributes
     async def load_policy_rules(self, _old: KresConfig, new: KresConfig, force: bool = False) -> Result[NoneType, str]:
         try:
             async with self._manager_lock:
+                if _old.cache.size_max != new.cache.size_max:
+                    logger.debug("Unlinking shared cache top memory")
+                    try:
+                        os.unlink(str(_old.cache.storage) + "/top")
+                    except FileNotFoundError:
+                        pass
+
                 logger.debug("Running kresd 'policy-loader'")
                 await self._run_policy_loader(new)
 
