@@ -44,7 +44,7 @@ from knot_resolver.utils.systemd_notify import systemd_notify
 from .config_store import ConfigStore
 from .constants import PID_FILE_NAME, init_user_constants
 from .exceptions import KresManagerException
-from .logging import logger_init
+from .logger import logger_init
 from .manager import KresManager
 
 logger = logging.getLogger(__name__)
@@ -111,13 +111,23 @@ class Server:
     ) -> Result[None, str]:
         if config_old.management != config_new.management:
             return Result.err(
-                "/server/management: Changing management API address/uTruenix-socket dynamically is not allowed as it's really dangerous."
+                "/server/management: Changing management API address/unix-socket dynamically is not allowed as it's really dangerous."
                 " If you really need this feature, please contact the developers and explain why. Technically,"
                 " there are no problems in supporting it. We are only blocking the dynamic changes because"
                 " we think the consequences of leaving this footgun unprotected are worse than its usefulness."
             )
         return Result.ok(None)
 
+    async def _deny_cache_garbage_collector_changes(
+        self, config_old: KresConfig, config_new: KresConfig, _force: bool = False
+    ) -> Result[None, str]:
+        if config_old.cache.garbage_collector != config_new.cache.garbage_collector:
+            return Result.err(
+                "/cache/garbage-collector/*: Changing configuration dynamically is not allowed."
+                " To change this configuration, you must edit the configuration file and restart the entire resolver."
+            )
+        return Result.ok(None)
+
     async def _reload_config(self, force: bool = False) -> None:
         if self._config_path is None:
             logger.warning("The manager was started with inlined configuration - can't reload")
@@ -184,6 +194,7 @@ class Server:
         self._setup_routes()
         await self.runner.setup()
         await self.config_store.register_verifier(self._deny_management_changes)
+        await self.config_store.register_verifier(self._deny_cache_garbage_collector_changes)
         await self.config_store.register_on_change_callback(self._reconfigure)
 
     async def wait_for_shutdown(self) -> None:
