@@ -1,4 +1,4 @@
-#!/usr/bin/python3
+#!/usr/bin/env python3
 
 import sys
 
@@ -25,7 +25,7 @@ def parse_junit_xml(filename):
 
 new = sys.argv[1]
 old = sys.argv[2]
-with open(sys.argv[3]) as f:
+with open(sys.argv[3], encoding="utf-8") as f:
     modified_tests = [line.strip() for line in f.readlines()]
 
 test_diffs = parse_junit_xml(old) ^ parse_junit_xml(new)
