@@ -1,7 +1,10 @@
 import glob
+import logging
+import shutil
 import os
 import re
 from collections import namedtuple
+import lief
 
 import pytest
 import yaml
@@ -16,24 +19,27 @@ def config_sanity_check(config_dict, config_name):
     mandatory_keys = {'name', 'binary', 'templates', 'configs', 'additional'}
     for cfg in config_dict['programs']:
         missing_keys = mandatory_keys - set(cfg.keys())
-        assert not missing_keys, 'Mandatory fields in configuration are missing: %s' % missing_keys
+        assert not missing_keys, f'Mandatory fields in configuration are missing: {missing_keys}'
 
         # sanity check templates vs. configs
-        assert len(cfg['templates']) == len(cfg['configs']),\
-            ('Number of jinja2 template files is not equal '
-             'to number of config files to be generated for '
-             'program "%s" (%s), i.e. len(templates) != len(configs)'
-             % (cfg['name'], config_name))
+        assert len(cfg['templates']) == len(cfg['configs']), \
+            (
+                'Number of jinja2 template files is not equal '
+                'to number of config files to be generated for '
+                f'program "{cfg["name"]}" ({config_name}), i.e. len(templates) != len(configs)'
+            )
 
         for additional in cfg["additional"]:
-            assert isinstance(additional, str),\
-                "All additional arguments in yaml should be strings. (%s, %s)"\
-                % (cfg['name'], config_name)
+            assert isinstance(additional, str), \
+                (
+                    "All additional arguments in yaml should be strings. "
+                    f"({cfg['name']}, {config_name})"
+                )
 
 
 def get_qmin_config(path):
     """Reads configuration from the *.rpl file and determines query-minimization setting."""
-    with open(path) as f:
+    with open(path, encoding='utf-8') as f:
         for line in f:
             if re.search(r"^CONFIG_END", line) or re.search(r"^SCENARIO_BEGIN", line):
                 return None
@@ -44,26 +50,42 @@ def get_qmin_config(path):
     return None
 
 
-def scenarios(paths, configs):
+def check_jemalloc_link(config_dict):
+    # pylint: disable=no-member
+    for program in config_dict['programs']:
+        binary = lief.parse(shutil.which(program['binary']))
+        assert binary is not None
+        for lib in binary.libraries:
+            if re.search(r"libjemalloc\.so.*", lib) is not None:
+                logging.error("The binary '%s' is dynamically linked to "
+                              "libjemalloc, which is incompatible with faketime. "
+                              "Use --force-run to ignore this check", program['name'])
+                pytest.skip("libjemalloc")
+
+
+def scenarios(paths, configs, force_run):
     """Returns list of *.rpl files from given path and packs them with their minimization setting"""
 
-    assert len(paths) == len(configs),\
+    assert len(paths) == len(configs), \
         "Number of --config has to be equal to number of --scenarios arguments."
 
     scenario_list = []
 
     for path, config in zip(paths, configs):
-        with open(config) as f:
+        with open(config, encoding='utf-8') as f:
             config_dict = yaml.load(f, yaml.SafeLoader)
         config_sanity_check(config_dict, config)
 
+        if not force_run:
+            check_jemalloc_link(config_dict)
+
         if os.path.isfile(path):
             filelist = [path]  # path to single file, accept it
         else:
             filelist = sorted(glob.glob(os.path.join(path, "*.rpl")))
 
         if not filelist:
-            raise ValueError('no *.rpl files found in path "{}"'.format(path))
+            raise ValueError(f'no *.rpl files found in path "{path}"')
 
         for file in filelist:
             scenario_list.append(Scenario(file, get_qmin_config(file), config_dict))
@@ -86,6 +108,8 @@ def pytest_addoption(parser):
     parser.addoption("--scenarios", action="append", help="directory with .rpl files")
     parser.addoption("--retries", action="store", help=("number of retries per"
                                                         "test when Deckard is under load"))
+    parser.addoption("--force-run", action="store_true", default=False,
+                     help="disable libjemalloc link check")
 
 
 def pytest_generate_tests(metafunc):
@@ -104,7 +128,10 @@ def pytest_generate_tests(metafunc):
         else:
             paths = metafunc.config.option.scenarios
 
-        metafunc.parametrize("scenario", scenarios(paths, configs), ids=str)
+        metafunc.parametrize("scenario",
+                             scenarios(paths, configs, metafunc.config.getoption("--force-run")),
+                             ids=str)
+
     if 'rpl_path' in metafunc.fixturenames:
         paths = metafunc.config.option.scenarios
         metafunc.parametrize("rpl_path", rpls(paths), ids=str)
@@ -123,4 +150,4 @@ def pytest_collection_modifyitems(items):
 
 
 def pytest_runtest_setup(item):  # pylint: disable=unused-argument
-    LinuxNamespace("user").__enter__()
+    LinuxNamespace("user").__enter__()  # pylint: disable=unnecessary-dunder-call
