@@ -50,32 +50,32 @@ def test_config_defaults():
     config = KresConfig()
 
     # DNS64 default
-    assert config.dns64 == False
+    assert config.dns64.enable == False
 
 
 def test_dnssec_false():
-    config = KresConfig({"dnssec": False})
+    config = KresConfig({"dnssec": {"enable": False}})
 
-    assert config.dnssec == False
+    assert config.dnssec.enable == False
 
 
 def test_dnssec_default_true():
     config = KresConfig()
 
     # DNSSEC defaults
-    assert config.dnssec.trust_anchor_sentinel == True
-    assert config.dnssec.trust_anchor_signal_query == True
-    assert config.dnssec.time_skew_detection == True
-    assert config.dnssec.refresh_time == None
+    assert config.dnssec.enable == True
+    assert config.dnssec.sentinel == True
+    assert config.dnssec.signal_query == True
     assert config.dnssec.trust_anchors == None
-    assert config.dnssec.negative_trust_anchors == None
     assert config.dnssec.trust_anchors_files == None
-    assert int(config.dnssec.keep_removed) == 0
-    assert str(config.dnssec.hold_down_time) == "30d"
+    assert config.dnssec.negative_trust_anchors == None
 
 
 def test_dns64_prefix_default():
-    assert str(KresConfig({"dns64": True}).dns64.prefix) == "64:ff9b::/96"
+    config = KresConfig({"dns64": {"enable": True}})
+
+    assert config.dns64.enable == True
+    assert str(config.dns64.prefix) == "64:ff9b::/96"
 
 
 def test_config_json_schema():
