@@ -45,17 +45,17 @@ def test_listen_port_defaults(listen: Dict[str, Any], port: Optional[int]):
         {"unix-socket": "/tmp/kresd-socket"},
         {"unix-socket": ["/tmp/kresd-socket", "/tmp/kresd-socket2"]},
         {"interface": "::1"},
-        {"interface": "::1@5353"},
-        {"interface": "::1", "port": 5353},
+        {"interface": "::1@5335"},
+        {"interface": "::1", "port": 5335},
         {"interface": ["127.0.0.1", "::1"]},
-        {"interface": ["127.0.0.1@5353", "::1@5353"]},
-        {"interface": ["127.0.0.1", "::1"], "port": 5353},
+        {"interface": ["127.0.0.1@5335", "::1@5335"]},
+        {"interface": ["127.0.0.1", "::1"], "port": 5335},
         {"interface": "lo"},
-        {"interface": "lo@5353"},
-        {"interface": "lo", "port": 5353},
+        {"interface": "lo@5335"},
+        {"interface": "lo", "port": 5335},
         {"interface": ["lo", "eth0"]},
-        {"interface": ["lo@5353", "eth0@5353"]},
-        {"interface": ["lo", "eth0"], "port": 5353},
+        {"interface": ["lo@5335", "eth0@5335"]},
+        {"interface": ["lo", "eth0"], "port": 5335},
     ],
 )
 def test_listen_valid(listen: Dict[str, Any]):
@@ -67,12 +67,12 @@ def test_listen_valid(listen: Dict[str, Any]):
     [
         {"unix-socket": "/tmp/kresd-socket", "port": "53"},
         {"interface": "::1", "unix-socket": "/tmp/kresd-socket"},
-        {"interface": "::1@5353", "port": 5353},
-        {"interface": ["127.0.0.1", "::1@5353"]},
-        {"interface": ["127.0.0.1@5353", "::1@5353"], "port": 5353},
-        {"interface": "lo@5353", "port": 5353},
-        {"interface": ["lo", "eth0@5353"]},
-        {"interface": ["lo@5353", "eth0@5353"], "port": 5353},
+        {"interface": "::1@5335", "port": 5335},
+        {"interface": ["127.0.0.1", "::1@5335"]},
+        {"interface": ["127.0.0.1@5335", "::1@5335"], "port": 5335},
+        {"interface": "lo@5335", "port": 5335},
+        {"interface": ["lo", "eth0@5335"]},
+        {"interface": ["lo@5335", "eth0@5335"], "port": 5335},
     ],
 )
 def test_listen_invalid(listen: Dict[str, Any]):
@@ -83,11 +83,11 @@ def test_listen_invalid(listen: Dict[str, Any]):
 @pytest.mark.parametrize(
     "tls",
     [
-        {"files-watchdog": "auto"},
-        {"files-watchdog": True},
-        {"files-watchdog": False},
+        {"watchdog": "auto"},
+        {"watchdog": True},
+        {"watchdog": False},
     ],
 )
-def test_tls_files_watchdog(tls: Dict[str, Any]):
-    expected: bool = WATCHDOG_LIB if tls["files-watchdog"] == "auto" else tls["files-watchdog"]
-    assert TLSSchema(tls).files_watchdog == expected
+def test_tls_watchdog(tls: Dict[str, Any]):
+    expected: bool = WATCHDOG_LIB if tls["watchdog"] == "auto" else tls["watchdog"]
+    assert TLSSchema(tls).watchdog == expected
