@@ -2,9 +2,10 @@
 #pragma once
 
 #include "kr_cache_gc.h"
+#include "lib/cache/top.h"
 
 typedef uint8_t category_t;
 
 #define CATEGORIES 100		// number of categories
 
-category_t kr_gc_categorize(gc_record_info_t * info);
+category_t kr_gc_categorize(struct kr_cache_top *top, gc_record_info_t * info, void *key, size_t key_len);
