@@ -21,12 +21,12 @@ typedef int (*kr_gc_iter_callback)(const knot_db_val_t * key,
 int kr_gc_cache_iter(knot_db_t * knot_db, const  kr_cache_gc_cfg_t *cfg,
 			kr_gc_iter_callback callback, void *ctx);
 
-/** Return RR type corresponding to the key or negative error code.
+/** Return RR type corresponding to the key, KNOT_CACHE_RTT or negative error code.
  *
- * Error is returned on unexpected values (those also trigger assertion)
- * and on other kinds of data in cache (e.g. struct rtt_state).
+ * Error is returned on unexpected values (those also trigger assertion).
  */
 int kr_gc_key_consistent(knot_db_val_t key);
+#define KNOT_CACHE_RTT 0x10000
 
 /** Printf a *binary* string in a human-readable way. */
 void debug_printbin(const char *str, unsigned int len);
